@@ -254,9 +254,10 @@ class OpenStackShell(app.App):
             metavar='<interface>',
             dest='interface',
             choices=['admin', 'public', 'internal'],
-            default=utils.env(
-                'OS_INTERFACE',
-                default=DEFAULT_INTERFACE),
+            # do not set default value inside utils.env() else user's cloud
+            # config key 'interface' will be ignored. Use OSC_Config's ctor
+            # option 'override_defaults' below instead.
+            default=utils.env('OS_INTERFACE'),
             help=_('Select an interface type.'
                    ' Valid interface types: [admin, public, internal].'
                    ' default=%s, (Env: OS_INTERFACE)') % DEFAULT_INTERFACE,
@@ -408,7 +409,7 @@ class OpenStackShell(app.App):
             self.cloud_config = cloud_config.OSC_Config(
                 pw_func=prompt_for_password,
                 override_defaults={
-                    'interface': None,
+                    'interface': DEFAULT_INTERFACE,
                     'auth_type': self._auth_type,
                 },
             )
@@ -496,9 +497,13 @@ class OpenStackShell(app.App):
         self.log.debug('clean_up %s: %s', cmd.__class__.__name__, err or '')
 
         # Close SDK connection if available to have proper cleanup there
-        if self.client_manager.sdk_connection:
+        if hasattr(self.client_manager, "sdk_connection"):
             self.client_manager.sdk_connection.close()
 
+        # Close session if available
+        if hasattr(self.client_manager.session, "session"):
+            self.client_manager.session.session.close()
+
         # Process collected timing data
         if self.options.timing:
             # Get session data
